---
---

@import "minima";

// Custom styles for Fal MCP Server docs

// Hero section
.hero-section {
  text-align: center;
  padding: 60px 0;
  background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
  color: white;
  border-radius: 10px;
  margin-bottom: 40px;
}

.hero-title {
  font-size: 3em;
  margin-bottom: 20px;
}

.hero-subtitle {
  font-size: 1.3em;
  opacity: 0.9;
  margin-bottom: 30px;
}

// CTA buttons
.cta-buttons {
  display: flex;
  gap: 20px;
  justify-content: center;
  flex-wrap: wrap;
}

.btn {
  display: inline-block;
  padding: 12px 30px;
  text-decoration: none;
  border-radius: 5px;
  transition: all 0.3s;
  font-weight: 600;
}

.btn-primary {
  background-color: #4CAF50;
  color: white;
  &:hover {
    background-color: #45a049;
    transform: translateY(-2px);
  }
}

.btn-secondary {
  background-color: white;
  color: #333;
  &:hover {
    background-color: #f0f0f0;
    transform: translateY(-2px);
  }
}

// Feature grid
.features-grid {
  display: grid;
  grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
  gap: 30px;
  margin: 40px 0;
}

.feature-card {
  padding: 30px;
  border: 1px solid #e0e0e0;
  border-radius: 10px;
  transition: all 0.3s;
  
  &:hover {
    box-shadow: 0 5px 15px rgba(0,0,0,0.1);
    transform: translateY(-5px);
  }
  
  .feature-icon {
    font-size: 3em;
    margin-bottom: 15px;
  }
  
  h3 {
    color: #333;
    margin-bottom: 15px;
  }
  
  ul {
    list-style: none;
    padding-left: 0;
    
    li:before {
      content: "✓ ";
      color: #4CAF50;
      font-weight: bold;
    }
  }
}

// Deployment grid
.deployment-grid {
  display: grid;
  grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
  gap: 20px;
  margin: 30px 0;
}

.deployment-option {
  padding: 20px;
  background: #f8f9fa;
  border-radius: 8px;
  text-align: center;
  
  h3 {
    color: #495057;
    margin-bottom: 10px;
  }
  
  code {
    display: block;
    margin: 10px 0;
    padding: 10px;
    background: #212529;
    color: #f8f9fa;
    border-radius: 4px;
  }
}

// Models table
.models-table {
  overflow-x: auto;
  margin: 30px 0;
  
  table {
    width: 100%;
    border-collapse: collapse;
    
    th {
      background: #667eea;
      color: white;
      padding: 12px;
      text-align: left;
    }
    
    td {
      padding: 10px;
      border-bottom: 1px solid #e0e0e0;
    }
    
    tr:hover {
      background: #f8f9fa;
    }
  }
}

// Navigation buttons
.nav-buttons {
  display: flex;
  justify-content: space-between;
  margin-top: 50px;
  padding-top: 30px;
  border-top: 1px solid #e0e0e0;
}

// Footer CTA
.footer-cta {
  text-align: center;
  padding: 40px;
  background: #f8f9fa;
  border-radius: 10px;
  margin-top: 50px;
  
  h2 {
    margin-bottom: 20px;
  }
  
  .btn-large {
    padding: 15px 40px;
    font-size: 1.2em;
  }
}

// Code highlighting improvements
pre {
  background: #282c34;
  color: #abb2bf;
  padding: 15px;
  border-radius: 5px;
  overflow-x: auto;
}

code {
  background: #f0f0f0;
  padding: 2px 6px;
  border-radius: 3px;
  font-size: 0.9em;
}

pre code {
  background: transparent;
  padding: 0;
}

// Mobile responsive
@media (max-width: 768px) {
  .hero-title {
    font-size: 2em;
  }
  
  .features-grid {
    grid-template-columns: 1fr;
  }
  
  .deployment-grid {
    grid-template-columns: 1fr;
  }
  
  .nav-buttons {
    flex-direction: column;
    gap: 10px;
    
    .btn {
      width: 100%;
      text-align: center;
    }
  }
}